
.. _authors:

=======
Authors
=======

DocuBox is written and maintained by Hiroshi Miura <miurahr@linux.com>


All contributors, listed alphabetically, are:

* (TBA)

and many other participants and contributors.
If you find a missing name to record, please feel free to tell me.